@@ -1,13 +1,17 @@
-# Copyright (C) 2015-2019  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from typing import Optional
+
+from rest_framework.request import Request
+
 from swh.web.api import utils
 from swh.web.api.apidoc import api_doc, format_docstring
 from swh.web.api.apiurls import api_route
 from swh.web.api.views.utils import api_lookup
-from swh.web.common import archive
+from swh.web.utils import archive
 
 
 @api_route(
@@ -20,9 +24,9 @@ from swh.web.common import archive
     "api-1-directory",
     checksum_args=["sha1_git"],
 )
-@api_doc("/directory/")
+@api_doc("/directory/", category="Archive")
 @format_docstring()
-def api_directory(request, sha1_git, path=None):
+def api_directory(request: Request, sha1_git: str, path: Optional[str] = None):
     """
     .. http:get:: /api/1/directory/(sha1_git)/[(path)/]
 
