@@ -1,36 +1,18 @@
-# Copyright (C) 2021  The Software Heritage developers
+# Copyright (C) 2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
 import attr
-from hypothesis import given
-from hypothesis.strategies import composite, sampled_from, sets
+from hypothesis import given, settings
+from hypothesis.strategies import sets
 import pytest
 
-from swh.model.hypothesis_strategies import (
-    raw_extrinsic_metadata as raw_extrinsic_metadata_orig,
-)
-from swh.model.hypothesis_strategies import sha1_git
-from swh.model.swhids import ExtendedObjectType, ExtendedSWHID, ObjectType
-from swh.web.common.utils import reverse
+from swh.model.hypothesis_strategies import raw_extrinsic_metadata
+from swh.model.model import Origin
 from swh.web.tests.api.views.utils import scroll_results
-from swh.web.tests.utils import check_api_get_responses, check_http_get_response
-
-
-# public Web API endpoint for raw extrinsic metadata does not support
-# extended SWHIDs so we ensure only core ones will be used in test inputs.
-@composite
-def raw_extrinsic_metadata(draw):
-    remd = draw(raw_extrinsic_metadata_orig())
-    remd = attr.evolve(
-        remd,
-        target=ExtendedSWHID(
-            object_type=ExtendedObjectType(draw(sampled_from(ObjectType)).value),
-            object_id=draw(sha1_git()),
-        ),
-    )
-    return attr.evolve(remd, id=remd.compute_hash())
+from swh.web.tests.helpers import check_api_get_responses, check_http_get_response
+from swh.web.utils import reverse
 
 
 @given(raw_extrinsic_metadata())
@@ -61,6 +43,9 @@ def test_api_raw_extrinsic_metadata(api_client, subtest, metadata):
         expected_result["discovery_date"] = expected_result[
             "discovery_date"
         ].isoformat()
+        if expected_result["target"].startswith(("swh:1:ori:", "swh:1:emd:")):
+            # non-core SWHID are hidden from the API
+            del expected_result["target"]
         assert rv.data == [expected_result]
 
         rv = check_http_get_response(api_client, metadata_url, status_code=200)
@@ -72,6 +57,41 @@ def test_api_raw_extrinsic_metadata(api_client, subtest, metadata):
         assert rv.content == metadata.metadata
 
 
+@settings(max_examples=1)
+@given(raw_extrinsic_metadata())
+def test_api_raw_extrinsic_metadata_origin_filename(api_client, subtest, metadata):
+    # ensure archive_data fixture will be reset between each hypothesis
+    # example test run
+    @subtest
+    def test_inner(archive_data):
+        nonlocal metadata
+        origin = Origin(url="http://example.com/repo.git")
+        metadata = attr.evolve(metadata, target=origin.swhid())
+        metadata = attr.evolve(metadata, id=metadata.compute_hash())
+        archive_data.origin_add([origin])
+        archive_data.metadata_authority_add([metadata.authority])
+        archive_data.metadata_fetcher_add([metadata.fetcher])
+        archive_data.raw_extrinsic_metadata_add([metadata])
+
+        authority = metadata.authority
+        url = reverse(
+            "api-1-raw-extrinsic-metadata-swhid",
+            url_args={"target": str(metadata.target)},
+            query_params={"authority": f"{authority.type.value} {authority.url}"},
+        )
+        rv = check_api_get_responses(api_client, url, status_code=200)
+
+        assert len(rv.data) == 1
+        metadata_url = rv.data[0]["metadata_url"]
+        rv = check_http_get_response(api_client, metadata_url, status_code=200)
+        assert rv["Content-Type"] == "application/octet-stream"
+        assert (
+            rv["Content-Disposition"]
+            == 'attachment; filename="http_example_com_repo_git_metadata"'
+        )
+        assert rv.content == metadata.metadata
+
+
 @pytest.mark.parametrize("limit", [1, 2, 10, 100])
 @given(sets(raw_extrinsic_metadata(), min_size=1))
 def test_api_raw_extrinsic_metadata_scroll(api_client, subtest, limit, meta):
@@ -112,12 +132,15 @@ def test_api_raw_extrinsic_metadata_scroll(api_client, subtest, limit, meta):
             expected_result["discovery_date"] = expected_result[
                 "discovery_date"
             ].isoformat()
+            if expected_result["target"].startswith(("swh:1:ori:", "swh:1:emd:")):
+                # non-core SWHID are hidden from the API
+                del expected_result["target"]
 
         assert len(results) == len(expected_results)
 
         for result in results:
             del result["metadata_url"]
-            assert result in expected_results
+            assert result in expected_results, str(expected_results)
 
 
 _swhid = "swh:1:dir:a2faa28028657859c16ff506924212b33f0e1307"
@@ -212,3 +235,21 @@ def test_api_raw_extrinsic_metadata_list_authorities(api_client, subtest, metada
         ]
 
         assert rv.data == expected_results
+
+
+def test_api_raw_extrinsic_metadata_origin_redirect(api_client, archive_data):
+    origin = Origin(url="http://example.com/repo.git")
+    archive_data.origin_add([origin])
+
+    url = reverse(
+        "api-1-raw-extrinsic-metadata-origin-authorities",
+        url_args={"origin_url": origin.url},
+    )
+    rv = check_http_get_response(api_client, url, status_code=302)
+
+    redirect_url = reverse(
+        "api-1-raw-extrinsic-metadata-swhid-authorities",
+        url_args={"target": str(origin.swhid())},
+    )
+
+    assert rv["location"] == redirect_url
