@@ -1,4 +1,4 @@
-# Copyright (C) 2018-2021  The Software Heritage developers
+# Copyright (C) 2018-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -13,7 +13,6 @@ from typing import Dict, List, Optional, Set
 
 from swh.core.config import merge_configs
 from swh.counters import get_counters
-from swh.indexer.ctags import CtagsIndexer
 from swh.indexer.fossology_license import FossologyLicenseIndexer
 from swh.indexer.mimetype import MimetypeIndexer
 from swh.indexer.storage import get_indexer_storage
@@ -41,7 +40,7 @@ from swh.web.browse.utils import (
     prepare_content_for_display,
     re_encode_content,
 )
-from swh.web.common import archive
+from swh.web.utils import archive
 
 # Module used to initialize data that will be provided as tests input
 
@@ -111,23 +110,6 @@ _TEST_LICENSE_INDEXER_CONFIG = merge_configs(
 )
 
 
-_TEST_CTAGS_INDEXER_CONFIG = merge_configs(
-    _TEST_INDEXER_BASE_CONFIG,
-    {
-        "workdir": "/tmp/swh/indexer.ctags",
-        "languages": {"c": "c"},
-        "tools": {
-            "name": "universal-ctags",
-            "version": "~git7859817b",
-            "configuration": {
-                "command_line": """ctags --fields=+lnz --sort=no --links=no """
-                """--output-format=json <filepath>"""
-            },
-        },
-    },
-)
-
-
 # Lightweight git repositories that will be loaded to generate
 # input data for tests
 _TEST_ORIGINS = [
@@ -204,6 +186,7 @@ ORIGIN_METADATA_KEY = "keywords"
 ORIGIN_METADATA_VALUE = "git"
 
 ORIGIN_MASTER_REVISION = {}
+ORIGIN_MASTER_DIRECTORY = {}
 
 
 def _add_origin(
@@ -325,21 +308,23 @@ def _init_tests_data():
                     # Add some origin intrinsic metadata for tests
                     metadata = common_metadata
                     metadata.update(origin.get("metadata", {}))
+                    revision = storage.revision_get([branch_data.target])[0]
                     origin_metadata = OriginIntrinsicMetadataRow(
                         id=origin["url"],
-                        from_revision=branch_data.target,
+                        from_directory=revision.directory,
                         indexer_configuration_id=idx_tool["id"],
                         metadata=metadata,
                         mappings=[],
                     )
                     idx_storage.origin_intrinsic_metadata_add([origin_metadata])
-                    search.origin_update(
-                        [{"url": origin["url"], "intrinsic_metadata": metadata}]
-                    )
+                    search.origin_update([{"url": origin["url"], "jsonld": metadata}])
 
                     ORIGIN_MASTER_REVISION[origin["url"]] = hash_to_hex(
                         branch_data.target
                     )
+                    ORIGIN_MASTER_DIRECTORY[origin["url"]] = hash_to_hex(
+                        revision.directory
+                    )
             elif target_type == "release":
                 release = storage.release_get([branch_data.target])[0]
                 origin_revisions.add(release.target)
@@ -494,7 +479,6 @@ def _init_indexers(tests_data):
     for idx_name, idx_class, idx_config in (
         ("mimetype_indexer", MimetypeIndexer, _TEST_MIMETYPE_INDEXER_CONFIG),
         ("license_indexer", FossologyLicenseIndexer, _TEST_LICENSE_INDEXER_CONFIG),
-        ("ctags_indexer", CtagsIndexer, _TEST_CTAGS_INDEXER_CONFIG),
     ):
         idx = idx_class(config=idx_config)
         idx.storage = tests_data["storage"]
